# -*- coding: utf-8 -*-

"""
app config
"""

from django.apps import AppConfig

from . import __version__


class AaTimezonesConfig(AppConfig):
    """AaTimezonesConfig"""

    name = "timezones"
    label = "timezones"
    verbose_name = "AA Timezones v{}".format(__version__)



# -*- coding: utf-8 -*-

"""
app settings
"""

from .utils import clean_setting

# set default panels if none are set in local.py
AA_TIMEZONES_ADDITIONAL_PANELS = clean_setting(
    "AA_TIMEZONES_ADDITIONAL_PANELS",
    [
        {
            "timezoneName": "US/Pacific",
            "panelTitle": "US / Pacific",
            "panelId": "us-pacific",
        },
        {
            "timezoneName": "US/Mountain",
            "panelTitle": "US / Mountain",
            "panelId": "us-mountain",
        },
        {
            "timezoneName": "US/Central",
            "panelTitle": "US / Central",
            "panelId": "us-central",
        },
        {
            "timezoneName": "US/Eastern",
            "panelTitle": "US / Eastern",
            "panelId": "us-eastern",
        },
        {
            "timezoneName": "Europe/London",
            "panelTitle": "EU / Western",
            "panelId": "eu-western",
        },
        {
            "timezoneName": "Europe/Berlin",
            "panelTitle": "EU / Central",
            "panelId": "eu-central",
        },
        {
            "timezoneName": "Europe/Istanbul",
            "panelTitle": "EU / Eastern",
            "panelId": "eu-eastern",
        },
        {
            "timezoneName": "Europe/Moscow",
            "panelTitle": "Russia / Moscow",
            "panelId": "russia-moscow",
        },
        {
            "timezoneName": "Asia/Shanghai",
            "panelTitle": "Russia / Siberia & China / Shanghai",
            "panelId": "asia-shanghai",
        },
        {
            "timezoneName": "Australia/ACT",
            "panelTitle": "Australia / Sydney",
            "panelId": "australia-atc",
        },
    ],
)



# -*- coding: utf-8 -*-

"""
the views
"""

from django.contrib.auth.decorators import login_required, permission_required
from django.shortcuts import render

from . import __title__
from .app_settings import AA_TIMEZONES_ADDITIONAL_PANELS


@login_required
@permission_required("timezones.basic_access")
def index(request):
    """
    index view

    :param request:
    :return:
    """
    context = {"title": __title__, "timezonePanelData": AA_TIMEZONES_ADDITIONAL_PANELS}

    return render(request, "timezones/index.html", context)
